==> dxcr-vue-cesium-0.0.1.tgz: package/lib/extend/krigingmap/index.js <==
/**
 * vue-cesium - https://github.com/zouyaoji/vue-cesium
 * Vue 2.x components for CesiumJS.
 *
 * @package VueCesium
 * @author zouyaoji <370681295@qq.com>
 * @version 2.1.6
 * @license MIT
 * @homepage https://zouyaoji.top/vue-cesium
 * @copyright (c) 2018-2020, zouyaoji <370681295@qq.com>
 */
import _parseFloat from '@babel/runtime-corejs2/core-js/parse-float';
import _regeneratorRuntime from '@babel/runtime-corejs2/regenerator';
import _Promise from '@babel/runtime-corejs2/core-js/promise';
import cmp from '../../mixins/virtualCmp';
import kriging from '@sakitam-gis/kriging';
import { featureCollection, point } from '@turf/helpers';
import isobands from '@turf/isobands';

var script = {
  name: 'vc-kriging-map',
  data: function data() {
    return {
      material1: {},
      hierarchy1: {},
      data: null,
      datasourceOptions: {
        clampToGround: true
      },
      nowaiting: true
    };
  },
  mixins: [cmp],
  props: {
    values: Array,
    lngs: Array,
    lats: Array,
    krigingModel: {
      type: String,
      default: 'exponential' // gaussian spherical exponential

    },
    krigingSigma2: {
      type: Number,
      default: 0
    },
    krigingAlpha: {
      type: Number,
      default: 100
    },
    canvasAlpha: {
      type: Number,
      default: 0.75
    },
    colors: {
      type: Array,
      default: function _default() {
        return ['#006837', '#1a9850', '#66bd63', '#a6d96a', '#d9ef8b', '#ffffbf', '#fee08b', '#fdae61', '#f46d43', '#d73027', '#a50026'];
      }
    },
    breaks: {
      type: Array,
      default: function _default() {
        return [0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0];
      }
    },
    clipCoords: {
      type: Array | String,
      default: function _default() {
        return [];
      }
    },
    show: {
      type: Boolean,
      default: true
    }
  },
  created: function created() {
    var _this = this;

    this._creatPromise = new _Promise(function (resolve, reject) {
      _this._resolve = resolve;
      _this._reject = reject;
    });
  },
  mounted: function mounted() {
    var _this2 = this;

    this.getParent(this.$parent).createPromise.then(function _callee(_ref) {
      var Cesium, viewer, values, lngs, lats, krigingModel, krigingSigma2, krigingAlpha, breaks, clipCoords, variogram, coordinates, requstData, coords, i, j, rectangle, extent, grid, fc, collection, isobandsResult;
      return _regeneratorRuntime.async(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              Cesium = _ref.Cesium, viewer = _ref.viewer;
              values = _this2.values, lngs = _this2.lngs, lats = _this2.lats, krigingModel = _this2.krigingModel, krigingSigma2 = _this2.krigingSigma2, krigingAlpha = _this2.krigingAlpha, breaks = _this2.breaks, clipCoords = _this2.clipCoords;
              variogram = kriging.train(values, lngs, lats, krigingModel, krigingSigma2, krigingAlpha);
              coordinates = [];

              if (!(clipCoords instanceof Array)) {
                _context.next = 8;
                break;
              }

              coordinates = clipCoords;
              _context.next = 13;
              break;

            case 8:
              if (!(typeof clipCoords === 'string')) {
                _context.next = 13;
                break;
              }

              _context.next = 11;
              return _regeneratorRuntime.awrap(Cesium.Resource.fetchJson(clipCoords));

            case 11:
              requstData = _context.sent;
              coordinates = requstData.features[0].geometry.coordinates;

            case 13:
              coords = [];

              for (i = 0; i < coordinates[0].length; i++) {
                for (j = 0; j < 2; j++) {
                  coords.push(coordinates[0][i][j]);
                }
              }

              if (coords.length > 4) {
                rectangle = Cesium.PolygonGeometry.computeRectangle({
                  polygonHierarchy: new Cesium.PolygonHierarchy(Cesium.Cartesian3.fromDegreesArray(coords))
                });
              } else {
                rectangle = Cesium.Rectangle.fromDegrees(coords[0], coords[1], coords[2], coords[3]);
              } // this.hierarchy1 = new Cesium.PolygonHierarchy(
              //   Cesium.Cartesian3.fromDegreesArray(coords)
              // )


              extent = [Cesium.Math.toDegrees(rectangle.west), Cesium.Math.toDegrees(rectangle.south), Cesium.Math.toDegrees(rectangle.east), Cesium.Math.toDegrees(rectangle.north)];
              grid = kriging.grid(coordinates, variogram, (extent[2] - extent[0]) / 200);
              fc = _this2.gridFeatureCollection(grid, [extent[0], extent[2]], [extent[1], extent[3]]);
              collection = featureCollection(fc); // console.log(collection)

              isobandsResult = isobands(collection, breaks, {
                zProperty: 'value'
              }); // console.log(isobandsResult)
              // function sortArea (a, b) {
              //   return area(b) - area(a)
              // }
              // 按照面积对图层进行排序，规避turf的一个bug
              // isobandsResult.features.sort(sortArea)

              _this2.data = isobandsResult;

              _this2._resolve(true);

            case 23:
            case "end":
              return _context.stop();
          }
        }
      });
    });
  },
  methods: {
    createCesiumObject: function createCesiumObject() {
      var _this3 = this;

      return _regeneratorRuntime.async(function createCesiumObject$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              return _context2.abrupt("return", this._creatPromise.then(function () {
                return _this3.$refs.geojsonDatasource.createPromise.then(function (_ref2) {
                  var Cesium = _ref2.Cesium,
                      viewer = _ref2.viewer,
                      cesiumObject = _ref2.cesiumObject;
                  var setPolygonColor = _this3.setPolygonColor;

                  if (!_this3.$refs.geojsonDatasource._mounted) {
                    return _this3.$refs.geojsonDatasource.load().then(function (_ref3) {
                      var Cesium = _ref3.Cesium,
                          viewer = _ref3.viewer,
                          cesiumObject = _ref3.cesiumObject;
                      return setPolygonColor(cesiumObject);
                    });
                  } else {
                    return setPolygonColor(cesiumObject);
                  }
                });
              }));

            case 1:
            case "end":
              return _context2.stop();
          }
        }
      }, null, this);
    },
    setPolygonColor: function setPolygonColor(cesiumObject) {
      var breaks = this.breaks,
          colors = this.colors;
      cesiumObject.entities.values.reduce(function (pre, cur) {
        var index = breaks.indexOf(_parseFloat(cur.properties.getValue().value.split('-')[0]));
        cur.polygon.material = Cesium.Color.fromCssColorString(colors[index]);
        cur.polygon.outline = false;
      }, []);
      return cesiumObject;
    },
    gridFeatureCollection: function gridFeatureCollection(grid, xlim, ylim) {
      // var range = grid.zlim[1] - grid.zlim[0]
      var i, j, x, y, z;
      var n = grid.data.length; // 列数

      var m = grid.data[0].length; // 行数

      var pointArray = [];

      for (i = 0; i < n; i++) {
        for (j = 0; j < m; j++) {
          x = i * grid.width + grid.xlim[0];
          y = j * grid.width + grid.ylim[0]; // z = (grid.data[i][j] - grid.zlim[0]) / range

          z = grid.data[i][j]; // if (z < 0.0) z = 0.0
          // if (z > 1.0) z = 1.0

          pointArray.push(point([x, y], {
            value: z
          }));
        }
      }

      return pointArray;
    },
    mount: function mount() {
      return _regeneratorRuntime.async(function mount$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              return _context3.abrupt("return", true);

            case 1:
            case "end":
              return _context3.stop();
          }
        }
      });
    },
    unmount: function unmount() {
      return _regeneratorRuntime.async(function unmount$(_context4) {
        while (1) {
          switch (_context4.prev = _context4.next) {
            case 0:
              return _context4.abrupt("return", this.$refs.geojsonDatasource && this.$refs.geojsonDatasource.unload());

            case 1:
            case "end":
              return _context4.stop();
          }
        }
      }, null, this);
    }
  }
};

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('i', {
    class: _vm.$options.name,
    staticStyle: {
      "display": "none !important"
    }
  }, [_vm.data !== null ? _c('vc-datasource-geojson', {
    ref: "geojsonDatasource",
    attrs: {
      "data": _vm.data,
      "options": _vm.datasourceOptions,
      "show": _vm.show
    }
  }) : _vm._e()], 1);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* component normalizer */

function __vue_normalize__(template, style, script, scope, functional, moduleIdentifier, createInjector, createInjectorSSR) {
  var component = (typeof script === 'function' ? script.options : script) || {}; // For security concerns, we use only base name in production mode.

  component.__file = "VcKrigingMap.vue";

  if (!component.render) {
    component.render = template.render;
    component.staticRenderFns = template.staticRenderFns;
    component._compiled = true;
    if (functional) component.functional = true;
  }

  component._scopeId = scope;

  return component;
}
/* style inject */

/* style inject SSR */


var VcKrigingMap = __vue_normalize__({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__);

function plugin(Vue) {

  if (plugin.installed) {
    return;
  }

  plugin.installed = true;
  Vue.component(VcKrigingMap.name, VcKrigingMap);
}

export default plugin;
export { VcKrigingMap, plugin as install };

==> dxcr-vue-cesium-0.0.2.tgz: package/lib/extend/krigingmap/index.js <==
/**
 * vue-cesium - https://github.com/zouyaoji/vue-cesium
 * Vue 2.x components for CesiumJS.
 *
 * @package VueCesium
 * @author zouyaoji <370681295@qq.com>
 * @version 2.2.0
 * @license MIT
 * @homepage https://zouyaoji.top/vue-cesium
 * @copyright (c) 2018-2021, zouyaoji <370681295@qq.com>
 */
import _parseFloat from '@babel/runtime-corejs2/core-js/parse-float';
import _regeneratorRuntime from '@babel/runtime-corejs2/regenerator';
import _Promise from '@babel/runtime-corejs2/core-js/promise';
import cmp from '../../mixins/virtualCmp';
import kriging from '@sakitam-gis/kriging';
import { featureCollection, point } from '@turf/helpers';
import isobands from '@turf/isobands';
import * as GeoJsonDataSource from '../../datasource/geojson';

var script = {
  name: 'vc-kriging-map',
  data: function data() {
    return {
      coordinates: {
        west: 0,
        south: 0,
        east: 0,
        north: 0
      },
      data: null,
      datasourceOptions: {
        clampToGround: true
      },
      nowaiting: true
    };
  },
  mixins: [cmp],
  props: {
    values: Array,
    lngs: Array,
    lats: Array,
    krigingModel: {
      type: String,
      default: 'exponential' // gaussian spherical exponential

    },
    krigingSigma2: {
      type: Number,
      default: 0
    },
    krigingAlpha: {
      type: Number,
      default: 100
    },
    canvasAlpha: {
      type: Number,
      default: 1
    },
    colors: {
      type: Array,
      default: function _default() {
        return ['#006837', '#1a9850', '#66bd63', '#a6d96a', '#d9ef8b', '#ffffbf', '#fee08b', '#fdae61', '#f46d43', '#d73027', '#a50026'];
      }
    },
    breaks: {
      type: Array,
      default: function _default() {
        return [0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9, 1.0];
      }
    },
    clipCoords: {
      type: [Array, String],
      default: function _default() {
        return [];
      }
    },
    show: {
      type: Boolean,
      default: true
    },
    cell: Number
  },
  created: function created() {
    var _this = this;

    this._creatPromise = new _Promise(function (resolve, reject) {
      _this._resolve = resolve;
      _this._reject = reject;
    });
  },
  mounted: function mounted() {
    var _this2 = this;

    this.getParent(this.$parent).createPromise.then(function _callee(_ref) {
      var Cesium, viewer, values, lngs, lats, krigingModel, krigingSigma2, breaks, clipCoords, krigingAlpha, variogram, coordinates, requstData, coords, i, j, rectangle, extent, grid, fc, collection, isobandsResult;
      return _regeneratorRuntime.async(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              Cesium = _ref.Cesium, viewer = _ref.viewer;
              values = _this2.values, lngs = _this2.lngs, lats = _this2.lats, krigingModel = _this2.krigingModel, krigingSigma2 = _this2.krigingSigma2, breaks = _this2.breaks, clipCoords = _this2.clipCoords, krigingAlpha = _this2.krigingAlpha;
              variogram = kriging.train(values, lngs, lats, krigingModel, krigingSigma2, krigingAlpha);
              coordinates = [];

              if (!(clipCoords instanceof Array)) {
                _context.next = 8;
                break;
              }

              if (clipCoords.length > 0 && clipCoords[0][0]) {
                // 传的是 geojson 面
                coordinates = clipCoords;
              } else {
                // 传的是一个 bounds 数组 (左下和右上)
                coordinates.push([[clipCoords[0], clipCoords[1]], [clipCoords[0], clipCoords[3]], [clipCoords[2], clipCoords[3]], [clipCoords[2], clipCoords[1]]]);
              }

              _context.next = 13;
              break;

            case 8:
              if (!(typeof clipCoords === 'string')) {
                _context.next = 13;
                break;
              }

              _context.next = 11;
              return _regeneratorRuntime.awrap(Cesium.Resource.fetchJson(clipCoords));

            case 11:
              requstData = _context.sent;
              coordinates = requstData.features[0].geometry.coordinates;

            case 13:
              coords = [];

              for (i = 0; i < coordinates[0].length; i++) {
                for (j = 0; j < 2; j++) {
                  coords.push(coordinates[0][i][j]);
                }
              }

              if (coords.length > 4) {
                rectangle = Cesium.PolygonGeometry.computeRectangle({
                  polygonHierarchy: new Cesium.PolygonHierarchy(Cesium.Cartesian3.fromDegreesArray(coords))
                });
              } else {
                rectangle = Cesium.Rectangle.fromDegrees(coords[0], coords[1], coords[2], coords[3]);
              }

              _this2.coordinates = rectangle;
              extent = [Cesium.Math.toDegrees(rectangle.west), Cesium.Math.toDegrees(rectangle.south), Cesium.Math.toDegrees(rectangle.east), Cesium.Math.toDegrees(rectangle.north)];
              grid = kriging.grid(coordinates, variogram, _this2.cell ? _this2.cell : (extent[2] - extent[0]) / 200);
              fc = _this2.gridFeatureCollection(grid, [extent[0], extent[2]], [extent[1], extent[3]]);
              collection = featureCollection(fc); // console.log(collection)

              isobandsResult = isobands(collection, breaks, {
                zProperty: 'value'
              }); // console.log(isobandsResult)
              // const sortArea = (a, b) => {
              //   return area(b) - area(a)
              // }
              // // 按照面积对图层进行排序，规避turf的一个bug
              // isobandsResult.features.sort(sortArea)

              _this2.data = isobandsResult;

              _this2._resolve(true);

            case 24:
            case "end":
              return _context.stop();
          }
        }
      });
    });
  },
  methods: {
    createCesiumObject: function createCesiumObject() {
      var _this3 = this;

      return _regeneratorRuntime.async(function createCesiumObject$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              return _context2.abrupt("return", this._creatPromise.then(function () {
                return _this3.$refs.geojsonDatasource.createPromise.then(function (_ref2) {
                  var Cesium = _ref2.Cesium,
                      viewer = _ref2.viewer,
                      cesiumObject = _ref2.cesiumObject;
                  var setPolygonColor = _this3.setPolygonColor;

                  if (!_this3.$refs.geojsonDatasource._mounted) {
                    return _this3.$refs.geojsonDatasource.load().then(function (_ref3) {
                      var Cesium = _ref3.Cesium,
                          viewer = _ref3.viewer,
                          cesiumObject = _ref3.cesiumObject;
                      return setPolygonColor(cesiumObject);
                    });
                  } else {
                    return setPolygonColor(cesiumObject);
                  }
                });
              }));

            case 1:
            case "end":
              return _context2.stop();
          }
        }
      }, null, this);
    },
    setPolygonColor: function setPolygonColor(cesiumObject) {
      var breaks = this.breaks,
          colors = this.colors,
          canvasAlpha = this.canvasAlpha;
      cesiumObject.entities.values.reduce(function (pre, cur) {
        var value = cur.properties.getValue(Cesium.JulianDate.now).value;
        var breakValue = value.substr(0, value.lastIndexOf('-'));
        var index = breaks.indexOf(_parseFloat(breakValue));
        cur.polygon.material = Cesium.Color.fromCssColorString(colors[index]).withAlpha(canvasAlpha);
        cur.polygon.outline = false;
        return true;
      }, []);
      return cesiumObject;
    },
    gridFeatureCollection: function gridFeatureCollection(grid, xlim, ylim) {
      // var range = grid.zlim[1] - grid.zlim[0]
      var i, j, x, y, z;
      var n = grid.data.length; // 列数

      var m = grid.data[0].length; // 行数

      var pointArray = [];

      for (i = 0; i < n; i++) {
        for (j = 0; j < m; j++) {
          x = i * grid.width + grid.xlim[0];
          y = j * grid.width + grid.ylim[0]; // z = (grid.data[i][j] - grid.zlim[0]) / range

          z = grid.data[i][j]; // if (z < 0.0) z = 0.0
          // if (z > 1.0) z = 1.0

          pointArray.push(point([x, y], {
            value: z
          }));
        }
      }

      return pointArray;
    },
    mount: function mount() {
      return _regeneratorRuntime.async(function mount$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              return _context3.abrupt("return", true);

            case 1:
            case "end":
              return _context3.stop();
          }
        }
      });
    },
    unmount: function unmount() {
      return _regeneratorRuntime.async(function unmount$(_context4) {
        while (1) {
          switch (_context4.prev = _context4.next) {
            case 0:
              return _context4.abrupt("return", this.$refs.geojsonDatasource && this.$refs.geojsonDatasource.unload());

            case 1:
            case "end":
              return _context4.stop();
          }
        }
      }, null, this);
    }
  }
};

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('i', {
    class: _vm.$options.name,
    staticStyle: {
      "display": "none !important"
    }
  }, [_vm.data !== null ? _c('vc-datasource-geojson', {
    ref: "geojsonDatasource",
    attrs: {
      "data": _vm.data,
      "options": _vm.datasourceOptions,
      "show": _vm.show
    }
  }) : _vm._e()], 1);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* component normalizer */

function __vue_normalize__(template, style, script, scope, functional, moduleIdentifier, createInjector, createInjectorSSR) {
  var component = (typeof script === 'function' ? script.options : script) || {}; // For security concerns, we use only base name in production mode.

  component.__file = "VcKrigingMap.vue";

  if (!component.render) {
    component.render = template.render;
    component.staticRenderFns = template.staticRenderFns;
    component._compiled = true;
    if (functional) component.functional = true;
  }

  component._scopeId = scope;

  return component;
}
/* style inject */

/* style inject SSR */


var VcKrigingMap = __vue_normalize__({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__);

function plugin(Vue) {

  if (plugin.installed) {
    return;
  }

  plugin.installed = true;
  Vue.use(GeoJsonDataSource);
  Vue.component(VcKrigingMap.name, VcKrigingMap);
}

export default plugin;
export { VcKrigingMap, plugin as install };
